﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Linq;
using System.Text;

namespace SE2017.GeoTools.Shapes
{
    internal class Ellipse : GeoBase, IGeoObject
    {
        double l1;
        double l2;
        PointF position;

        public Ellipse()
        {
        }
        public Ellipse(List<KeyValuePair<string, double>> args)
        {
            position = new PointF(0,0);
            foreach (var pair in args)
            {
                if (pair.Key == "w")
                    l1 = pair.Value;
                else if (pair.Key == "h")
                    l2 = pair.Value;
                else if (pair.Key == "x")
                    position.X = (float)(pair.Value);
                else if (pair.Key == "y")
                    position.Y = (float)(pair.Value);
            }
        }
        public Ellipse(double x, double y, double l1, double l2)
        {
            this.l1 = l1;
            this.l2 = l2;
            position = new PointF((float)x, (float)y);
        }

        public double HRadius
        {
            get { return l1; }
            set { l1 = value; }
        }
        public double VRadius
        {
            get { return l2; }
            set { l2 = value; }
        }
        public double[][] Points
        {
            get 
            {
                GraphicsPath gp = new GraphicsPath();
                gp.AddEllipse(new RectangleF(position.X, position.Y, (float)(l1 + l1), (float)(l2 + l2)));
                double[][] retVal = new double[gp.PathPoints.Length][];
                for (int i = 0; i < gp.PathPoints.Length; i++)
                {
                    retVal[i] = new double[] { gp.PathPoints[i].X, gp.PathPoints[i].Y };
                }
                return retVal;
            }
        }
        public override double Area { get { return l1 * l2 * Math.PI; } }
        public override double Perimeter { get { return 2 * Math.PI * Math.Sqrt((l1 * l1 + l2 * l2) / 2); } }
        public PointF Position { get { return position; } }

        public override string ToString()
        {
            return "ellipse [location:(" + position.X + "," + position.Y + "), radii:" + l1 + "," + l2 + "]";
        }

        public override void Draw(Graphics g)
        {
            g.DrawEllipse(new Pen(Brushes.Green, 5), (float)position.X, (float)position.Y, (float)(2 * l1), (float)(2 * l2));
        }
    }
}
