﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using GeoTools.General;
using System.Drawing;

namespace GeoTools.Shapes
{
    public class Triangle: GeoBase, IGeoObject
    {
        public Triangle()
        { }
        public Triangle(double a, double b, double c, double d, double e, double f)
        {
            Points = new double[][]
            {
                new double[] {a, b},
                new double[] {c, d},
                new double[] {e, f}
            };
        }
        public Triangle(PointF p1, PointF p2, PointF p3)
        {
            Points = new double[][]
            {
                new double[] {p1.X, p1.Y},
                new double[] {p2.X, p2.Y},
                new double[] {p3.X, p3.Y}
            };
        }
        public double[][] Points {  get; private set; }

        public double Perimeter
        {
            get
            {
                return Distance(Points[0], Points[1])
                    + Distance(Points[1], Points[2])
                    + Distance(Points[0], Points[2]);
            }
        }

        public double Area
        {
            get
            {
                double s = Perimeter / 2;
                return Math.Sqrt(s
                    * (s - Distance(Points[0], Points[1]))
                    * (s - Distance(Points[1], Points[2]))
                    * (s - Distance(Points[0], Points[2]))
                    );
            }
        }

        public override void Draw(System.Drawing.Graphics g)
        {
            g.DrawLines(Pens.Green, new PointF[]
                {
                    new PointF((float)Points[0][0], (float)Points[0][1]),
                    new PointF((float)Points[1][0], (float)Points[1][1]),
                    new PointF((float)Points[2][0], (float)Points[2][1]),
                    new PointF((float)Points[0][0], (float)Points[0][1]),
                });
        }
        public override string ToString()
        {
            return "triangle [ "
                + String.Format("({0},{1}) ", Points[0][0], Points[0][1])
                + String.Format("({0},{1}) ", Points[1][0], Points[1][1])
                + String.Format("({0},{1}) ", Points[2][0], Points[2][1]) 
                + "]";
        }   
    }
}
